==> haskell-storable-complex-0.2.3.0-342-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-BPtJ9I5vs65q79rTBz8Gj
key:                  storable-complex-0.2.3.0-BPtJ9I5vs65q79rTBz8Gj
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  e0f90942dace1287067089fe0750d7b2
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-9.6.6/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/storable-complex-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-complex
hs-libraries:         HSstorable-complex-0.2.3.0-BPtJ9I5vs65q79rTBz8Gj
depends:
    base-4.18.2.1 base-orphans-0.9.3-JybUSC3tjiTK5xbDkdemoL

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-complex-0.2.3.0-343-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-complex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-complex
version:              0.2.3.0
visibility:           public
id:                   storable-complex-0.2.3.0-vGWvSF35UY7MwGapXOlKx
key:                  storable-complex-0.2.3.0-vGWvSF35UY7MwGapXOlKx
license:              BSD-3-Clause
maintainer:           Carter Schonwald <carter.schonwald@gmail.com>
author:               Jed Brown <jed@59A2.org>
homepage:             https://github.com/cartazio/storable-complex
synopsis:             Storable instance for Complex
description:
    Provides a Storable instance for Complex which is binary
    compatible with C99, C++ and Fortran complex data types.

    The only purpose of this package is to provide a standard
    location for this instance so that other packages needing
    this instance can play nicely together.

category:             Data
abi:                  086a60459f723e3dd761e648c52d86e1
exposed:              True
exposed-modules:      Foreign.Storable.Complex
import-dirs:          /usr/lib/ghc-9.6.6/site-local/storable-complex-0.2.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/storable-complex-0.2.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/storable-complex-0.2.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-complex
hs-libraries:         HSstorable-complex-0.2.3.0-vGWvSF35UY7MwGapXOlKx
depends:
    base-4.18.2.1 base-orphans-0.9.3-8K2HHrVXqhTGZegxAcDUaG

haddock-interfaces:
    /usr/share/doc/haskell-storable-complex/html/storable-complex.haddock

haddock-html:         /usr/share/doc/haskell-storable-complex/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
